==> wtp-sdk-R-1.5.4-200705021353.zip: org/eclipse/jst/j2ee/webservice/internal/WebServiceConstants.java <==
/*******************************************************************************
 * Copyright (c) 2001, 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jst.j2ee.webservice.internal;

public final class WebServiceConstants
{
  public static final String DEFAULT_XML_ENCODING = "UTF-8";//$NON-NLS-1$

  public static final String WEBSERVICE_DD_SHORT_NAME   = "webservices.xml"; //$NON-NLS-1$
  public static final String WEBSERVICE_SYSTEMID    = "http://www.ibm.com/webservices/dtd/j2ee_web_services_1_0.dtd"; //$NON-NLS-1$
  public static final String WEBSERVICE_PUBLICID = "-//IBM Corporation, Inc.//DTD J2EE Web services 1.0//EN"; //$NON-NLS-1$  
  public static final String WEBSERVICE_DOCTYPE = "webservices";//$NON-NLS-1$
  public static final String WEBSERVICE_SCHEMA_LOC = "http://www.ibm.com/webservices/xsd/j2ee_web_services_1_1.xsd";//$NON-NLS-1$
  public static final String WEBSERVICE_SCHEMA_LOC_SUN = "http://java.sun.com/xml/ns/j2ee/j2ee_web_services_1_1.xsd";//$NON-NLS-1$

  public static final String WEBSERVICECLIENT_DD_SHORT_NAME   = "webservicesclient.xml"; //$NON-NLS-1$
  public static final String WEBSERVICECLIENT_SYSTEMID    = "http://www.ibm.com/webservices/dtd/j2ee_web_services_client_1_0.dtd"; //$NON-NLS-1$
  public static final String WEBSERVICECLIENT_PUBLICID = "-//IBM Corporation, Inc.//DTD J2EE Web services client 1.0//EN"; //$NON-NLS-1$  
  public static final String WEBSERVICECLIENT_DOCTYPE = "webservicesclient";//$NON-NLS-1$

public static final String WEBSERVICE_TEMP_DD_SHORT_NAME = "webservices-temp.xml";//$NON-NLS-1$

  //public static final String JAXRPCMAP_DD_SHORT_NAME   = "mapping.xml"; //$NON-NLS-1$ !!We don't have a standard name!!
  public static final String JAXRPCMAP_SYSTEMID    = "http://www.ibm.com/webservices/dtd/j2ee_jaxrpc_mapping_1_0.dtd"; //$NON-NLS-1$
  public static final String JAXRPCMAP_PUBLICID = "-//IBM Corporation, Inc.//DTD J2EE JAX-RPC mapping 1.0//EN"; //$NON-NLS-1$  
  public static final String JAXRPCMAP_DOCTYPE = "java-wsdl-mapping";//$NON-NLS-1$
  public static final String JAXRPCMAP_SCHEMA_LOC = "http://www.ibm.com/webservices/xsd/j2ee_jaxrpc_mapping_1_1.xsd";//$NON-NLS-1$
  public static final String JAXRPCMAP_SCHEMA_LOC_SUN = "http://java.sun.com/xml/ns/j2ee/j2ee_jaxrpc_mapping_1_1.xsd";//$NON-NLS-1$
  
  

  public static final int WEBSERVICE_1_0_ID = 10;
  public static final int WEBSERVICE_1_1_ID = 11;
  public static final String WEBSERVICE_SCHEMA_VERSION = "1.1";//$NON-NLS-1$

}

==> wtp-sdk-R-3.0-20080616152118a.zip: org/eclipse/jst/j2ee/webservice/internal/WebServiceConstants.java <==
/*******************************************************************************
 * Copyright (c) 2001, 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jst.j2ee.webservice.internal;

public final class WebServiceConstants
{
  public static final String DEFAULT_XML_ENCODING = "UTF-8";//$NON-NLS-1$

  public static final String WEBSERVICE_DD_SHORT_NAME   = "webservices.xml"; //$NON-NLS-1$
  public static final String WEBSERVICE_SYSTEMID    = "http://www.ibm.com/webservices/dtd/j2ee_web_services_1_0.dtd"; //$NON-NLS-1$
  public static final String WEBSERVICE_PUBLICID = "-//IBM Corporation, Inc.//DTD J2EE Web services 1.0//EN"; //$NON-NLS-1$  
  public static final String WEBSERVICE_DOCTYPE = "webservices";//$NON-NLS-1$
  public static final String WEBSERVICE_SCHEMA_LOC_1_1 = "http://www.ibm.com/webservices/xsd/j2ee_web_services_1_1.xsd";//$NON-NLS-1$
  public static final String WEBSERVICE_SCHEMA_LOC_SUN_1_1 = "http://java.sun.com/xml/ns/j2ee/j2ee_web_services_1_1.xsd";//$NON-NLS-1$
  public static final String WEBSERVICE_SCHEMA_LOC_1_2 = "http://java.sun.com/xml/ns/javaee/javaee_web_services_1_2.xsd";//$NON-NLS-1$
  public static final String WEBSERVICE_SCHEMA_LOC_SUN_1_2 = "http://java.sun.com/xml/ns/javaee/javaee_web_services_1_2.xsd";//$NON-NLS-1$

  public static final String WEBSERVICECLIENT_DD_SHORT_NAME   = "webservicesclient.xml"; //$NON-NLS-1$
  public static final String WEBSERVICECLIENT_SYSTEMID    = "http://www.ibm.com/webservices/dtd/j2ee_web_services_client_1_0.dtd"; //$NON-NLS-1$
  public static final String WEBSERVICECLIENT_PUBLICID = "-//IBM Corporation, Inc.//DTD J2EE Web services client 1.0//EN"; //$NON-NLS-1$  
  public static final String WEBSERVICECLIENT_DOCTYPE = "webservicesclient";//$NON-NLS-1$

public static final String WEBSERVICE_TEMP_DD_SHORT_NAME = "webservices-temp.xml";//$NON-NLS-1$

  //public static final String JAXRPCMAP_DD_SHORT_NAME   = "mapping.xml"; //$NON-NLS-1$ !!We don't have a standard name!!
  public static final String JAXRPCMAP_SYSTEMID    = "http://www.ibm.com/webservices/dtd/j2ee_jaxrpc_mapping_1_0.dtd"; //$NON-NLS-1$
  public static final String JAXRPCMAP_PUBLICID = "-//IBM Corporation, Inc.//DTD J2EE JAX-RPC mapping 1.0//EN"; //$NON-NLS-1$  
  public static final String JAXRPCMAP_DOCTYPE = "java-wsdl-mapping";//$NON-NLS-1$
  public static final String JAXRPCMAP_SCHEMA_LOC = "http://www.ibm.com/webservices/xsd/j2ee_jaxrpc_mapping_1_1.xsd";//$NON-NLS-1$
  public static final String JAXRPCMAP_SCHEMA_LOC_SUN = "http://java.sun.com/xml/ns/j2ee/j2ee_jaxrpc_mapping_1_1.xsd";//$NON-NLS-1$
  
  

  public static final int WEBSERVICE_1_0_ID = 10;
  public static final int WEBSERVICE_1_1_ID = 11;
  public static final int WEBSERVICE_1_2_ID = 12;
  public static final String WEBSERVICE_SCHEMA_VERSION_1_1 = "1.1";//$NON-NLS-1$
  public static final String WEBSERVICE_SCHEMA_VERSION_1_2 = "1.2";//$NON-NLS-1$

}
